==> zopyx.ecardsng-0.1.0.tar.gz: zopyx.ecardsng-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
"""
This module contains the tool of zopyx.ecardsng
"""
import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

version = '0.1.0'

long_description = (
    read('README.txt')
    + '\n\n' +
    read(os.path.join('docs', 'HISTORY.txt'))
    )

tests_require=['zope.testing']

setup(name='zopyx.ecardsng',
      version=version,
      description="An ECard implementation for Plone",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: Zope Public License',
        ],
      keywords='Plone Zope ECards',
      author='Andreas Jung',
      author_email='info@zopyx.com',
      url='http://svn.plone.org/svn/plone/plone.example',
      license='ZPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['zopyx', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        'uuid',
                        # -*- Extra requirements: -*-
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'zopyx.ecardsng.tests.test_docs.test_suite',
      entry_points="""
      # -*- entry_points -*- 
      [distutils.setup_keywords]
      paster_plugins = setuptools.dist:assert_string_list

      [egg_info.writers]
      paster_plugins.txt = setuptools.command.egg_info:write_arg
      """,
      paster_plugins = ["ZopeSkel"],
      )

==> zopyx.ecardsng-0.3.1.tar.gz: zopyx.ecardsng-0.3.1/setup.py <==
# -*- coding: utf-8 -*-
"""
This module contains the tool of zopyx.ecardsng
"""
import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

version = '0.3.1'

long_description = (
    read('README.txt')
    + '\n\n' +
    read(os.path.join('docs', 'HISTORY.txt'))
    )

tests_require=['zope.testing']

setup(name='zopyx.ecardsng',
      version=version,
      description="An ECard implementation for Plone",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Plone',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: Zope Public License',
        ],
      keywords='Plone Zope ECards',
      author='Andreas Jung',
      author_email='info@zopyx.com',
      url='http://svn.plone.org/svn/collective/zopyx.ecardsng/trunk',
      license='ZPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['zopyx', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        'uuid',
                        # -*- Extra requirements: -*-
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'zopyx.ecardsng.tests.test_docs.test_suite',
      entry_points="""
      # -*- entry_points -*- 
      [distutils.setup_keywords]
      paster_plugins = setuptools.dist:assert_string_list

      [egg_info.writers]
      paster_plugins.txt = setuptools.command.egg_info:write_arg
      """,
      paster_plugins = ["ZopeSkel"],
      )
